@@ -1,6 +1,8 @@
 from typing import List, Optional
 from dataclasses import dataclass
 
+from ircstates import ChannelUser
+
 class Whois(object):
     server:      Optional[str]       = None
     server_info: Optional[str]       = None
@@ -11,7 +13,7 @@ class Whois(object):
     signon:      Optional[int]       = None
     idle:        Optional[int]       = None
 
-    channels:    Optional[List[str]] = None
+    channels:    Optional[List[ChannelUser]] = None
 
     nickname: str = ""
     username: str = ""
